#ifndef TDPAccountDescH
#define TDPAccountDescH

// ==========================================================================
// File:         TDPAccountDesc.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPAccountDesc Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPAccountDesc
// Description: The TDPAccountDesc component wraps the DirectX DPACCOUNTDESC 
//              structure which contains the account information for a 
//              specific player.   
//              
//              Use this component with TDx_Play::GetPlayerAccount() to 
//              obtain account information for a player logged into a secure 
//              session. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPAccountDesc : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPAccountDesc : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    AccountIDA
    // Description: The AccountID property references the account identifier, 
    //              stored as a ANSI string. 
    //              
    //              The account identifier uniquely describes a player who is 
    //              logged in to a secure session. 
    //              
    //              The account identifier's format will vary depending on 
    //              the Security Support Provider Interface (SSPI) package 
    //              that is being used. 
    // ----------------------------------------------------------------------
    __property AnsiString AccountIDA = { read=FGetAccountIDA, 
    write=FSetAccountIDA, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property contains the size in bytes of the 
    //              internal DPACCOUNTDESC structure. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, 
    default=sizeof(DPACCOUNTDESC) }; 

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPAccountDesc component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    AccountID
    // Description: The AccountID property references the account identifier, 
    //              stored as a Unicode string. 
    //              
    //              The account identifier uniquely describes a player who is 
    //              logged in to a secure session. 
    //              
    //              The account identifier's format will vary depending on 
    //              the Security Support Provider Interface (SSPI) package 
    //              that is being used. 
    // ----------------------------------------------------------------------
    __property AnsiString AccountID = { read=FGetAccountID, 
    write=FSetAccountID, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPAccountDesc method or 
    //              fget/fset. eg. DP_OK or DDERR_SURFACELOST or TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPAccountDesc's internal DPACCOUNTDESC structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear(); 

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPAccountDesc(TComponent* Owner); 
    virtual __fastcall ~TDPAccountDesc(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPACCOUNTDESC* Internal_DPACCOUNTDESC_Ptr = { 
    read=FGetInternal_DPACCOUNTDESC_Ptr, nodefault }; 

    void __fastcall Internal_DPACCOUNTDESC_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    AnsiString __fastcall FGetAccountID(); 
    void __fastcall FSetAccountID( AnsiString pAccountID ); 
    AnsiString __fastcall FGetAccountIDA(); 
    void __fastcall FSetAccountIDA( AnsiString pAccountIDA ); 
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPACCOUNTDESC* __fastcall FGetInternal_DPACCOUNTDESC_Ptr(); 
    void __fastcall FSetInternal_DPACCOUNTDESC( DPACCOUNTDESC* pDPACCOUNTDESC 
    ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    AnsiString fAccountID; 
    AnsiString fAccountIDA; 
    HRESULT fErrorValue; 

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPACCOUNTDESC fDPACCOUNTDESC; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
