#ifndef TDPChatH
#define TDPChatH

// ==========================================================================
// File:         TDPChat.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPChat Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPChat
// Description: The TDPChat component wraps the DirectX DPCHAT structure for 
//              holding a chat message. 
//              
//              Use this object to hold messages to be sent using 
//              TDx_Play::SendChatMessage(). 
//              
//              TDx_Play::SendChatMessage() must be used for player to player 
//              chatting within a lobby session, however, using this method 
//              is optional within an application session. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPChat : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPChat : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    MessageA
    // Description: The Message property references the  message being sent, 
    //              stored as an ANSI string. 
    // ----------------------------------------------------------------------
    __property AnsiString MessageA = { read=FGetMessageA, write=FSetMessageA, 
    nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property contains the size in bytes of the 
    //              internal DPCHAT structure. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, 
    default=sizeof(DPCHAT) }; 

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPChat component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPChat method or fget/fset. 
    //              eg. DP_OK or DDERR_SURFACELOST or TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Property:    Message
    // Description: The Message property references the  message being sent, 
    //              stored as a Unicode string. 
    // ----------------------------------------------------------------------
    __property AnsiString Message = { read=FGetMessage, write=FSetMessage, 
    nodefault }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPChat's internal DPCHAT structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear(); 

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPChat(TComponent* Owner); 
    virtual __fastcall ~TDPChat(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPCHAT* Internal_DPCHAT_Ptr = { read=FGetInternal_DPCHAT_Ptr, 
    nodefault }; 

    void __fastcall Internal_DPCHAT_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    AnsiString __fastcall FGetMessage(); 
    void __fastcall FSetMessage( AnsiString pMessage ); 
    AnsiString __fastcall FGetMessageA(); 
    void __fastcall FSetMessageA( AnsiString pMessageA ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPCHAT* __fastcall FGetInternal_DPCHAT_Ptr(); 
    void __fastcall FSetInternal_DPCHAT( DPCHAT* pDPCHAT ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    HRESULT fErrorValue; 
    AnsiString fMessage; 
    AnsiString fMessageA; 

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPCHAT fDPCHAT; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
