#ifndef TDPComPortAddressH
#define TDPComPortAddressH

// ==========================================================================
// File:         TDPComPortAddress.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPComPortAddress Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPComPortAddress
// Description: The TDPComPortAddress component wraps the DirectX 
//              DPCOMPORTADDRESS structure which holds COM port configuration 
//              information. 
//              
//              Use this component in TDPCompoundAddressElement::Data when 
//              TDPCompoundAddressElement::DataType is set to DPAID_ComPort. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPComPortAddress : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPComPortAddress : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    BaudRate
    // Description: The BaudRate property specifies the baud rate of the com 
    //              port. 
    //              
    //              The possible values are : 
    //              
    //              CBR_110 
    //              CBR_300 
    //              CBR_600   
    //              CBR_1200 
    //              CBR_2400 
    //              CBR_4800   
    //              CBR_9600 
    //              CBR_14400 
    //              CBR_19200   
    //              CBR_38400 
    //              CBR_56000 
    //              CBR_57600   
    //              CBR_115200 
    //              CBR_128000 
    //              CBR_256000   
    //              
    // ----------------------------------------------------------------------
    __property dword BaudRate = { read=FGetBaudRate, write=FSetBaudRate, 
    default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    ComPort
    // Description: The ComPort property defines which COM port is to be 
    //              used. 
    //              
    //              This property can contain a value of 1, 2, 3, or 4. 
    // ----------------------------------------------------------------------
    __property dword ComPort = { read=FGetComPort, write=FSetComPort, 
    default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    FlowControl
    // Description: The FlowControl property defines which method of flow 
    //              control is being used on the COM port. 
    //              
    //              The possible values are: 
    //              
    //              DPCPA_NOFLOW   No Flow Control. 
    //              DPCPA_DTRFLOW  Hardware DTR flow control. 
    //              DPCPA_RTSFLOW   Hardware RTS flow control 
    //              DPCPA_RTSDTRFLOW  Hardware RTS and DTR flow control. 
    //              DPCPA_XONXOFFFLOW  Software XON/XOFF flow control. 
    // ----------------------------------------------------------------------
    __property dword FlowControl = { read=FGetFlowControl, 
    write=FSetFlowControl, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    Parity
    // Description: The Parity property defines the COM port parity being 
    //              used. 
    //              
    //              The possible values are: 
    //              
    //              NOPARITY 
    //              ODDPARITY 
    //              EVENPARITY 
    //              MARKPARITY 
    // ----------------------------------------------------------------------
    __property dword Parity = { read=FGetParity, write=FSetParity, default=0 
    }; 

    // ----------------------------------------------------------------------
    // Property:    StopBits
    // Description: The StopBits property defines the number of stop bits the 
    //              com port uses. 
    //              
    //              The possible values are : 
    //              
    //              ONESTOPBIT 
    //              ONE5STOPBITS 
    //              TWOSTOPBITS 
    // ----------------------------------------------------------------------
    __property dword StopBits = { read=FGetStopBits, write=FSetStopBits, 
    default=0 }; 

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPComPortAddress component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPComPortAddress method or 
    //              fget/fset. eg. DP_OK or DDERR_SURFACELOST or TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property contains the size in bytes of the 
    //              internal DPCOMPORTADDRESS structure. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, nodefault }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPComPortAddress's internal DPCOMPORTADDRESS 
    //              structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear(); 

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPComPortAddress(TComponent* Owner); 
    virtual __fastcall ~TDPComPortAddress(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPCOMPORTADDRESS* Internal_DPCOMPORTADDRESS_Ptr = { 
    read=FGetInternal_DPCOMPORTADDRESS_Ptr, nodefault }; 

    void __fastcall Internal_DPCOMPORTADDRESS_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    dword __fastcall FGetBaudRate(); 
    void __fastcall FSetBaudRate( dword pBaudRate ); 
    dword __fastcall FGetComPort(); 
    void __fastcall FSetComPort( dword pComPort ); 
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    dword __fastcall FGetFlowControl(); 
    void __fastcall FSetFlowControl( dword pFlowControl ); 
    dword __fastcall FGetParity(); 
    void __fastcall FSetParity( dword pParity ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 
    dword __fastcall FGetStopBits(); 
    void __fastcall FSetStopBits( dword pStopBits ); 

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPCOMPORTADDRESS* __fastcall FGetInternal_DPCOMPORTADDRESS_Ptr(); 
    void __fastcall FSetInternal_DPCOMPORTADDRESS( DPCOMPORTADDRESS* 
    pDPCOMPORTADDRESS ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    HRESULT fErrorValue; 
    dword fSize; 

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPCOMPORTADDRESS fDPCOMPORTADDRESS; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
