#ifndef TDPLAppInfoH
#define TDPLAppInfoH

// ==========================================================================
// File:         TDPLAppInfo.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPLAppInfo Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPLAppInfo
// Description: The TDPLAppInfo component wraps the DirectX DPLAPPINFO 
//              structure which holds information from the Windows registry 
//              about the application being enumerated. 
//              
//              Use this component in the 
//              TDx_PlayLobby::OnEnumLocalApplications() callback event to 
//              hold information about the application being enumerated. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPLAppInfo : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPLAppInfo : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    AppNameA
    // Description: The AppNameA property references the name of the 
    //              application being enumerated, stored as an ANSI string. 
    // ----------------------------------------------------------------------
    __property AnsiString AppNameA = { read=FGetAppNameA, write=FSetAppNameA, 
    nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property contains the size in bytes of the 
    //              internal DPLAPPINFO structure. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, 
    default=sizeof(DPLAPPINFO) }; 

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPLAppInfo component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    AppName
    // Description: The AppNameA property references the name of the 
    //              application being enumerated, stored as a unicode string. 
    // ----------------------------------------------------------------------
    __property AnsiString AppName = { read=FGetAppName, write=FSetAppName, 
    nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    Application
    // Description: The Application property identifies the application being 
    //              enumerated. 
    // ----------------------------------------------------------------------
    __property GUID Application = { read=FGetApplication, 
    write=FSetApplication, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPLAppInfo method or 
    //              fget/fset. eg. DP_OK or DDERR_SURFACELOST or TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPLAppInfo's internal DPLAPPINFO structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear(); 

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPLAppInfo(TComponent* Owner); 
    virtual __fastcall ~TDPLAppInfo(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPLAPPINFO* Internal_DPLAPPINFO_Ptr = { 
    read=FGetInternal_DPLAPPINFO_Ptr, nodefault }; 

    void __fastcall Internal_DPLAPPINFO_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    AnsiString __fastcall FGetAppName(); 
    void __fastcall FSetAppName( AnsiString pAppName ); 
    AnsiString __fastcall FGetAppNameA(); 
    void __fastcall FSetAppNameA( AnsiString pAppNameA ); 
    GUID __fastcall FGetApplication(); 
    void __fastcall FSetApplication( GUID pApplication ); 
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPLAPPINFO* __fastcall FGetInternal_DPLAPPINFO_Ptr(); 
    void __fastcall FSetInternal_DPLAPPINFO( DPLAPPINFO* pDPLAPPINFO ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    AnsiString fAppName; 
    AnsiString fAppNameA; 
    GUID fApplication; 
    HRESULT fErrorValue; 

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPLAPPINFO fDPLAPPINFO; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
